## 1. Начальная установка

Для развертывания узла системы распределенного реестра (СРР) Innochain рекомендуется использовать сервер со следующими характеристиками:

1) Операционная система Ubuntu 18.04
2) Размер оперативной памяти: не менее 8GB
3) SSD жесткий диск размера не менее 64GB

Для начала работы необходимо установить ``docker``, используя следующие команды:

```
sudo apt update
sudo apt install apt-transport-https ca-certificates curl software-properties-common
curl -fsSL https://download.docker.com/linux/ubuntu/gpg | sudo apt-key add -
sudo add-apt-repository "deb [arch=amd64] https://download.docker.com/linux/ubuntu bionic stable"
sudo apt update
apt-cache policy docker-ce
sudo apt install docker-ce
```

Чтобы не использовать постоянно ``sudo`` для работы с докером рекомендуется исполнить следующую команду:
```
sudo usermod -aG docker ${USER}
```

Далее необходимо установить ``docker-compose``:

```
sudo curl -L https://github.com/docker/compose/releases/download/1.29.1/docker-compose-`uname -s`-`uname -m` -o /usr/local/bin/docker-compose
sudo chmod +x /usr/local/bin/docker-compose
```

## 2. Подготовка необходимых для запуска файлов

Далее необходимо распаковать архив дистрибутива и перейти в его корневую директорию. В корневой директори должны 
располагаться ``docker-compose.yml`` файл и директория ``node``.

Для сборов логов используется связка сервисов ``loki`` и ``grafana``, настройки которых находятся в директории ``node`` (local-config.yaml и grafana.ini соответственно). Так же необходимо установить плагин, используя следующую команду:

```
sudo docker plugin install grafana/loki-docker-driver:latest --alias loki --grant-all-permissions
```

## 4. Пояснение содержания файла docker-compose.yml

Наиболее важными контейнерами являют node (представляющий узел СРР) и api (представляющий интерфейс для интеграции с внешними клиентами: веб/мобильные приложения). Если система разворачивается локально, то никаких изменений в ``docker-compose.yml`` прозводить не надо. Однако если система разворачивается на удаленном сервере, то необходимо добавить в ALLOWED_HOSTS раздела ``api`` через пробел ip адрес удаленного (например, 188.0.1.1:8000) сервера.

## 5. Запуск проекта

Перейдите в директорию с файлом docker-compose.yml
Теперь можно запустить проект при помощи команды:
```
docker-compose -f docker-compose.yml -p node up -d
```
Где: 
- docker-compose.yml - название файла
- node - название проекта
- -d - флаг позволяющий запустить все сервисы в фоне

После запуска контейнеров станет доступен веб интерфейс для просмотра логов Grafana на порте 3000. 
Для получения доступа к логам необходимо слева снизу нажать Configuration > Data Sources, в появившемся меню выбрать Loki, затем необходимо прописать ``node_loki_1:3100`` в секции HTTP в поле URL и сохранить. Теперь можно отправлять запросы через explorer, который находится в меню слева. 
Сверху будет выпадающее меню в нём нужно выбрать loki как источник данных. Далее начните вводить {} и вам будут предложены подсказки, выберите job и дальше подсказка выдаст названия сервисов, выберите тот, логи которого хотите просмотреть (например, сервис узла - node).

Для проверки работоспособности системы можно использовать innochain-cli внутри контейнера узла для генерации транзакций. Команда ниже генерирует транзакцию создания аккаунта со случайным идентификатором

```
docker exec -w /root/node/node-ml/innochain-cli node_node_1 ./innochain-cli -u
```
Для отправки запроса апи нужно скопировать полученный вывод вместо транзакции в примере, указать адрес узла (если узел развернут локально то http://127.0.0.1:8000) и выполнить команду: 
```
curl -X POST '<ip:port узла>' --data '{"jsonrpc":"2.0","method":"submitRawTransaction","params":{"tx":"<транзакция>", "id": 1},"id":1}'
```

Для полной остановки и удаления контейнеров необходимо выполните команду: 
```
docker-compose -f docker-compose-example.yml -p node down
```